@@ -3,6 +3,6 @@ use procspawn::{self, spawn};
 #[allow(clippy::empty_loop)]
 fn main() {
     procspawn::init();
-    let handle = spawn((), |()| loop {});
+    let mut handle = spawn((), |()| loop {});
     handle.kill().unwrap();
 }
