@@ -59,8 +59,7 @@
 //!   backtraces are captured with the `backtrace-rs` crate and serialized
 //!   across process boundaries.
 //! * `test-support`: when this feature is enabled procspawn can be used
-//!   with rusttest.  See [`enable_test_support!`](macro.enable_test_support.html)
-//!   for more information.
+//!   with rusttest.  See [`testing`](#testing) for more information.
 //! * `json`: enables optional JSON serialization.  For more information see
 //!   [Bincode Limitations](#bincode-limitations).
 //!
@@ -73,6 +72,40 @@
 //! work around this you can enable the `json` feature and wrap affected objects
 //! in the [`Json`](struct.Json.html) wrapper to force JSON serialization.
 //!
+//! # Testing
+//!
+//! Due to limitations of the rusttest testing system there are some
+//! restrictions to how this crate operates.  First of all you need to enable
+//! the `test-support` feature for `procspawn` to work with rusttest at all.
+//! Secondly your tests need to invoke the
+//! [`enable_test_support!`](macro.enable_test_support.html) macro once
+//! top-level.
+//!
+//! With this done the following behavior applies:
+//!
+//! * Tests behave as if `procspawn::init` was called (that means with the
+//!   default arguments).  Other configuration is not supported.
+//! * procspawn will register a dummy test (named `procspawn_test_helper`)
+//!   which doesn't do anything when called directly, but acts as the spawning
+//!   helper for all `spawn` calls.
+//! * stdout is silenced by default unless `--show-output` or `--nocapture`
+//!   is passed to tests.
+//! * when trying to spawn with intercepted `stdout` be aware that there is
+//!   extra noise that will be emitted by rusttest.
+//!
+//! Example:
+//!
+//! ```rust,no_run
+//! procspawn::enable_test_support!();
+//!
+//! #[test]
+//! fn test_basic() {
+//!     let handle = procspawn::spawn((1, 2), |(a, b)| a + b);
+//!     let value = handle.join().unwrap();
+//!     assert_eq!(value, 3);
+//! }
+//! ```
+//!
 //! # Shared Libraries
 //!
 //! `procspawn` uses the [`findshlibs`](https://github.com/gimli-rs/findshlibs)
@@ -109,8 +142,6 @@
 //!
 //! More examples can be found in the example folder: [examples](https://github.com/mitsuhiko/procspawn/tree/master/examples)
 
-use serde::{Deserialize, Serialize};
-
 #[macro_use]
 mod proc;
 
@@ -128,28 +159,7 @@ pub mod testsupport;
 pub use self::core::{assert_spawn_is_safe, init, ProcConfig};
 pub use self::error::{Location, PanicInfo, SpawnError};
 pub use self::pool::{Pool, PoolBuilder};
-pub use self::proc::{Builder, JoinHandle};
+pub use self::proc::{spawn, Builder, JoinHandle};
 
 #[cfg(feature = "json")]
 pub use self::json::Json;
-
-/// Spawn a new process to run a function with some payload.
-///
-/// ```rust,no_run
-/// // call this early in your main() function.  This is where all spawned
-/// // functions will be invoked.
-/// procspawn::init();
-///
-/// let data = vec![1, 2, 3, 4];
-/// let handle = procspawn::spawn(data, |data| {
-///     println!("Received data {:?}", &data);
-///     data.into_iter().sum::<i64>()
-/// });
-/// let result = handle.join().unwrap();
-/// ```
-pub fn spawn<A: Serialize + for<'de> Deserialize<'de>, R: Serialize + for<'de> Deserialize<'de>>(
-    args: A,
-    f: fn(A) -> R,
-) -> JoinHandle<R> {
-    Builder::new().spawn(args, f)
-}
